.. Ringo documentation master file, created by
   sphinx-quickstart on Mon Mar 18 17:46:35 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Ringo's documentation!
=================================
This is the documentation of the Ringo application framework. After a short overview we
will explain the user interface and some basic concepts in Ringo.

.. toctree::
   :maxdepth: 3

   overview
   ui
   architecture
   development
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

